/* Hey Emacs, this is -*- C -*- code! */

/* Synched up with: Not synched with FSF. */

/* Think twice before editing this file.  Generated automatically by configure.

 The file startup.el guesses at reasonable values for load-path, exec-path,
 and lock-directory.  This means that if you move emacs and its associated
 sub-tree to a different place in the filesystem, or to a different machine,
 you won't have to do anything for it to work.

 If you define the paths in this file then they will take precedence over
 any value generated by the heuristic in startup.el.  The hardcoded paths
 will be checked to see if they are valid, in which case they will be used.
 Otherwise the editor will attempt to make its normal guess.

 See the NEWS file for a description of the heuristic used to locate the lisp
 and exec directories at startup time.  If you are looking at this file
 because you are having trouble, then you would be much better off arranging
 for those heuristics to succeed than defining the paths in this file.

   **  Let me say that again.  If you're editing this file, you're making
   **  a mistake.  Re-read the section on installation in ../etc/NEWS.

 If it defines anything, this file should define some subset of the following:

   PATH_PROGNAME        The name of the Emacs variant that's running.

   PATH_VERSION         The version id of the Emacs variant that's running.

   PATH_EXEC_PREFIX	The value of --exec-prefix.

   PATH_PREFIX		The value of --prefix.

   PATH_LOADSEARCH	The default value of `load-path'.

   PATH_MODULESEARCH	The default value of `module-load-path'.

   PATH_PACKAGEPATH     The default value of `package-path'.

   PATH_SITE            The default location of site-specific Lisp files.

   PATH_SITE_MODULES	The default location of site-specific modules.

   PATH_EXEC		The default value of `exec-directory' and `exec-path'.
			(exec-path also contains the value of whatever is in
			the PATH environment variable.)

   PATH_DATA		The default value of `data-directory'.  This
			is where architecture-independent files are
			searched for.

   PATH_INFO		This is where the info documentation is installed.

   PATH_INFOPATH	The default value of `Info-directory-list'.
			These are additional places info files are searched
			for. */

#define PATH_PROGNAME "xemacs"

#define PATH_VERSION "21.4.6"

#ifdef EXEC_PREFIX_USER_DEFINED
#define PATH_EXEC_PREFIX "/usr/local"
#endif

#ifdef PREFIX_USER_DEFINED
#define PATH_PREFIX "/usr/local"
#endif

#ifdef LISPDIR_USER_DEFINED
#define  PATH_LOADSEARCH "/usr/local/lib/xemacs-21.4.6/lisp"
#endif

#ifdef MODULEDIR_USER_DEFINED
#define  PATH_MODULESEARCH "/usr/local/lib/xemacs-21.4.6/i686-pc-cygwin/modules"
#endif

#ifdef SITELISPDIR_USER_DEFINED
#define  PATH_SITE "/usr/local/lib/xemacs/site-lisp"
#endif

#ifdef SITEMODULEDIR_USER_DEFINED
#define  PATH_SITE_MODULES "/usr/local/lib/xemacs/site-modules"
#endif

#ifdef PACKAGE_PATH_USER_DEFINED
#define PATH_PACKAGEPATH ""
#endif

#ifdef ARCHLIBDIR_USER_DEFINED
#define PATH_EXEC "/usr/local/lib/xemacs-21.4.6/i686-pc-cygwin"
#endif

#ifdef ETCDIR_USER_DEFINED
#define PATH_DATA "/usr/local/lib/xemacs-21.4.6/etc"
#endif

#ifdef DOCDIR_USER_DEFINED
#define PATH_DOC "/usr/local/lib/xemacs-21.4.6/i686-pc-cygwin"
#endif

#ifdef INFODIR_USER_DEFINED
#define PATH_INFO "/usr/local/lib/xemacs-21.4.6/info"
#endif

#ifdef INFOPATH_USER_DEFINED
#define PATH_INFOPATH ""
#endif
